Crate weather_icons

Crate weather_icons 

Structs

Moon
MoonBuilder

Enums

Condition
Icon
Style
The moons are split into 28 icons, to correspond neatly with the 28 day moon cycle. There is a primary set and alternate set. The primary set is meant to be interpreted as: where there are pixels, that is the illuminated part of the moon. The alternate set is meant to be interpreted as: where there are pixels, that is the shadowed part of the moon.
Time